@@ -9,5 +9,11 @@ ctest_parallel="no"
 if [[ ! $(command -v module > /dev/null 2>&1) ]]; then
   . /usr/local/apps/module/init/bash
 fi
+
 module unload grib_api
-module switch gnu clang/3.6.2
+module unload eccodes
+module unload emos
+module unload fftw
+module unload libemos
+
+module switch gnu clang
