@@ -95,7 +95,7 @@ long describe_input_field(grib_handle* handle, long outputRepresentation) {
     long scanningMode;
     long table;
     long date;
-    long bitmapPresent = 0;
+    long missingValuesPresent = 0;
     char *intf2_debug = getenv("INTF2_DEBUG");
     long localNumber = 0;
     char typeOfLevel[50]={0,};
@@ -336,25 +336,25 @@ long describe_input_field(grib_handle* handle, long outputRepresentation) {
         fprintf(stderr,"Parameter Number setup INTIN failed %d\n",err);
     }
 
-    /* If bitmap Present  */
-    if ((err = grib_get_long(handle,"bitmapPresent",&bitmapPresent))!= GRIB_SUCCESS)
+    /* If missing values present  */
+    if ((err = grib_get_long(handle,"missingValuesPresent",&missingValuesPresent))!= GRIB_SUCCESS)
     {
-        fprintf(stderr,"Cannot get bitmapPresent  %s\n",grib_get_error_message(err));
+        fprintf(stderr,"Cannot get missingValuesPresent %s\n",grib_get_error_message(err));
         return err;
     }
     /*  There are exeptions for a few centres  */
     if ((err = grib_get_long(handle,"centre",&centre)))
     {
-        fprintf(stderr,"Cannot get centre  %s\n",grib_get_error_message(err));
+        fprintf(stderr,"Cannot get centre %s\n",grib_get_error_message(err));
     }
     if(levelType == 100 && parameter == 129)
-        bitmapPresent = 0;
+        missingValuesPresent = 0;
 
     /* if(table == 128 && (parameter == 31 || parameter == 130)){ */
     /* Live emoslib to use its own values
      * Can Not set allways external missing value in case bitmap is Present because of some inconsistensy in LIBEMOS
      */
-    if(bitmapPresent) {
+    if(missingValuesPresent) {
         /* Try to play in a same style as Libemos
             missingValue = -2147483647.0;
             err = grib_set_double(handle,"missingValue",missingValue);
@@ -366,7 +366,7 @@ long describe_input_field(grib_handle* handle, long outputRepresentation) {
             fprintf(stderr,"Missing value %s\n",grib_get_error_message(err));
         }
         if(intf2_debug)
-            printf("DESCRIBE_INPUT_FIELD: BITMAP PRESENT Missing Value %f \n",missingValue);
+            printf("DESCRIBE_INPUT_FIELD: missingValuesPresent Missing Value %f \n",missingValue);
         if(err == GRIB_SUCCESS) {
             realv[0] = missingValue;
             text = "yes";
